'''
Created on May 02, 2015
import requests

@author: karpagm1
'''


    
class DictionaryEntry:
    
    def __init__(self):
        self.id = None
        self.uid = None
        self.externalUid = None
        self.createdDate = None
        self.modifiedDate = None
        self.name = None
        self.description = None
        self.entryType = None
        self.entryValue = None
        self.category = None
        self.parent = None



'''
Created on Apr 27, 2015
import requests

@author: karpagm1
'''
from dataObjects.ContactViewObject import ContactViewObject


    
class OrganizationViewObject:
    
    def __init__(self):
        self.id = None
        self.shortName = None
        self.name = None
        self.description = None
        self.type = None
        self.contactVo = ContactViewObject()
        self.contactPersonVos = None
        
        #private List<SubjectViewObject> contactPersonVos=new ArrayList<SubjectViewObject>();


'''
Created on Apr 27, 2015
import requests

@author: karpagm1
'''


    
class DnaCaseMap:
    
    def __init__(self):
        self.dnaCase =  None
        self.subjectMap = None
        self.profileMap = None
        self.subjectProfileMap = None
        self.subjectLousMap = {}
        self.validForImport = True
        self.reasonForFailure = None
        self.uid = None



import os,sys
import xlsxwriter #python3 -m easy_install xlsxwriter

class STRExport(object):
    def __init__(self,fileName):

        self.fileName = fileName
        self.workbook = xlsxwriter.Workbook(self.fileName)
        self.columns = ['sample_uid','sample_name','marker','allele','status','coverage','short sequence','long sequence','rsid']
        self.fontSize = 12

    def addWorksheet(self,name):
        if self.workbook:
            return self.workbook.add_worksheet(name)

    def setColumns(self,worksheet,columns):
        self.columns = columns

    def write(self,worksheet,rows):
        worksheet.set_column(0,len(self.columns),self.fontSize)
        worksheet.write('A1',"Verstion 1.0")
        worksheet.write_row('A2',self.columns)
        count = 2
        for row in rows:
                rowNum = "A" + str(count+1)
                worksheet.write_row(rowNum, row)
                count += 1









'''
Created on Apr 27, 2015
import requests

@author: karpagm1
'''


    
class LocusViewObject:
    
    def __init__(self):
        self.name = None
        self.classification = None
        self.locusType = None
        
    def __repr__(self):
        return {'name':self.name,'classification':self.classification,'locusType':self.locusType}    



from setuptools import setup

setup(
	name='hid_converge_batch',
	version='2.0.1',
	author='HID S/W',
	license='Thermofisher Scientific',
	packages=['ngs','service','utils'],
	install_requires=['hid_converge'],
	dependency_links=['https://pypi.python.org/pypi/hid_converge'],
	include_package_data=True,
	zip_safe=False
)


'''
Created on May 03, 2015
import requests

@author: karpagm1
'''
from enum import Enum

    
class MasterDataEnum(Enum):
    FBI = 'FBI'    
    GLO = 'GLO'   
    NGM = 'NGM'   
    NGS = 'NGS'  
    UNI = 'UNI'
    
    
    
    
    
    



'''
Created on Apr 27, 2015
import requests

@author: karpagm1
'''


    
class DnaCase:
    
    def __init__(self):
        self.id = None
        self.caseName = None
        self.externalUid = None
        self.caseType = None
        self.uid = None
        self.externalUid = None
        self.description = None
        self.requester = None
        self.barcode = None
        self.caseType = None
        self.requestingOrganization = None
        self.createdDate = None
        self.modifiedDate = None
        self.casePriority = None


'''
Created on Apr 27, 2015
import requests

@author: karpagm1
'''


    
class ContactViewObject:
    
    def __init__(self):
        self.id = None
        self.address = None
        self.city = None
        self.state = None
        self.zip = None
        self.country = None
        self.email = None
        self.workPhone = None
        self.homePhone = None
        self.mobilePhone = None



'''
Created on May 03, 2015
import requests

@author: karpagm1
'''
from enum import Enum

    
class Relationship(Enum):
    child = 'Child'
    father = 'Father'
    mother = 'Mother'
    maternalGrandfather = 'Maternal Grandfather'
    maternalGrandmother = 'Maternal Grandmother'
    paternalGrandfather = 'Paternal Grandfather'
    paternalGrandmother = 'Paternal Grandmother'
    
    
    
    
    



'''
Created on Apr 27, 2015
import requests

@author: karpagm1
'''

import logging
import json

from authentication.gateway import GateWayService
import xml.etree.ElementTree as et
import urllib
import re
from service import RelationshipEnum
from service.DictionaryEntry import DictionaryEntry
from QueueModule.q import flushableQ


title = 'person.title'
gender = 'Gender'
relationship = 'Relationship'
country = 'Country'
state = 'State'
    
class CaseService:
    
    def __init__(self):
        #print ('initialized')
        logging.INFO('initialized')

    # Case related related   API
    @staticmethod
    def createCase(dnaCase, baseUrl):
        CaseService.logService('createCase' )
        caseCreationUrl = baseUrl+'/platform/dnacase/dnaCase/'
        payload= json.dumps(dnaCase.__dict__)
        #response = authentication.session.post(caseCreationUrl, data=payload)
        return GateWayService.callConverge(caseCreationUrl, 'true', payload)

    @staticmethod    
    def addSubjectToCase(dnaCaseId, subject, baseUrl):
        CaseService.logService('addSubjectToCase' )
        addSubjectUrl = baseUrl+'/platform/dnacase/dnaCase/addsubject/'+str(dnaCaseId)+'/false'
        payload= json.dumps(subject.__dict__)
        flushableQ.put(dnaCaseId)
        return GateWayService.callConverge(addSubjectUrl,'true', payload)
    
    @staticmethod    
    def addProfileToCase(dnaCaseId, profiles, baseUrl):
        CaseService.logService('addProfileToCase' )
        addSubjectUrl = baseUrl+'/platform/dnacase/dnaCase/addAllProfiles/'+str(dnaCaseId)
        payload= json.dumps([p.__dict__ for p in profiles])
        flushableQ.put(dnaCaseId)
        #print(payload)
        return GateWayService.callConverge(addSubjectUrl,'true', payload)

    @staticmethod    
    def getAnalysisInput(dnaCaseId, baseUrl):
        CaseService.logService('getAnalysisInput' )
        addSubjectUrl = baseUrl+'/kinship/kinship/analysisInput/'+str(dnaCaseId)
        return GateWayService.callConverge(addSubjectUrl,'false', '')
    
    @staticmethod    
    def postAnalysisInput(dnaCaseId, baseUrl, analysisInput):
        CaseService.logService('postAnalysisInput' )
        addSubjectUrl = baseUrl+'/kinship/kinship/analysisInput/'+str(dnaCaseId)
        return GateWayService.callConverge(addSubjectUrl,'true', analysisInput)
    
    @staticmethod    
    def getPedigreeTreeXml(baseUrl, type):
        CaseService.logService('getPedigreeTreeXml' + type)
        addSubjectUrl = baseUrl+'/platform/common/dictionary/?category=Sys.Kinship.Tree.ImageTemplate&name='+type
        return GateWayService.callConverge(addSubjectUrl,'false', '')
    
    @staticmethod    
    def saveSessionImage(baseUrl, analysisId,image):
        CaseService.logService('saveSessionImage' )
        addSubjectUrl = baseUrl+'/kinship/kinship/saveSessionImage/'+str(analysisId)
        return GateWayService.callConverge(addSubjectUrl,'true', image)
    
    @staticmethod    
    def calculate(baseUrl,dnaCaseId, analysisId):
        CaseService.logService('calculate' )
        addSubjectUrl = baseUrl+'/kinship/kinship/calculate/'+str(dnaCaseId)+'/'+str(analysisId)
        return GateWayService.callConverge(addSubjectUrl,'true', '')
    
    @staticmethod    
    def saveAnalysisResults(baseUrl,dnaCaseId, analysisId, analysisResults):
        CaseService.logService('saveAnalysisResults' )
        addSubjectUrl = baseUrl+'/kinship/kinship/saveAnalysisResult/'+str(dnaCaseId)+'/'+str(analysisId)
        flushableQ.put(dnaCaseId)
        return GateWayService.callConverge(addSubjectUrl,'true', analysisResults)
    
    @staticmethod    
    def getSubjectsForDnaCase(baseUrl,dnaCaseId):
        CaseService.logService('getSubjectsForDnaCase')
        getSubjectsForDnaCaseUrl = baseUrl+'/kinship/kinship/getSubjectsForCaseForKinship/'+str(dnaCaseId)
        return GateWayService.callConverge(getSubjectsForDnaCaseUrl,'false', dnaCaseId)
    
    
    @staticmethod    
    def creatPedigreeTreeImageForCase1(baseUrl,dnaCaseId, analysisId):    
        subjectDict = CaseService.getSubjectsForDnaCase(baseUrl, dnaCaseId)
        subjectsJson = json.dumps(subjectDict)
        CaseService.createXmlConfigAndSaveSessionImage(baseUrl,subjectsJson,analysisId,414,919,'ScriptedTree')

    @staticmethod    
    def createXmlConfigAndSaveSessionImage(baseUrl,subjectDict,analysisID,height,width,modelName):
        CaseService.logService('createXmlConfig' )
        addSubjectUrl = baseUrl+'/kinship/kinship/createSaveSessionImage/'+str(analysisID)+'/'+str(height)+'/'+str(width)+'/'+modelName
        return GateWayService.callConverge(addSubjectUrl,'true', subjectDict)
    
    @staticmethod 
    def buildGraph(caseId, caseType, profilesDict, subjects):    
        graph = {'edges':[], 'vertices':[]}
        kinshipGraph = {'graph':graph,'motherNodeId':None, 'fatherNodeId':None , 'childNodeId':None, 'prosVertexId':None, 'defVertexId':None,
                        'untypedFatherNodeId':None, 'defMotherNodeId':None, 'defChildNodeId':None, 'defVertexId':None, 'untypedMotherNodeId': None,
                        'defChildNodeId':None, 'seqId':1}
        #print(profilesDict)
        for v in profilesDict:
            profileId = v['id']
            subjectId = v['subject']['id']
            gender = subjects[subjectId]['gender']
            relationship = subjects[subjectId]['relationship']
            #print(' profile ' + str(profileId) + ' subject ' +str(subjectId) + ' gender' + gender+ '  relaton ' + relationship)
            CaseService.buildProsecutionVertex(2, subjectId ,profileId, gender, relationship, kinshipGraph )
            CaseService.buildDefenceVertex(3,  subjectId ,profileId, gender, relationship, kinshipGraph)
        noOfSubjects = len (profilesDict);
        if(noOfSubjects == 3 and caseType == 'Trio Paternity'):
            CaseService.buildDefenceVertex(3, '', None, 'M', 'FUntyped', kinshipGraph)
        elif(noOfSubjects == 3 and caseType == 'Trio Maternity'):
            CaseService.buildDefenceVertex(3, '', None, 'F', 'MUntyped', kinshipGraph)    
        elif(noOfSubjects == 2 and caseType == 'Duo Motherless'):
            CaseService.buildDefenceVertex(3, '', None, 'M', 'FUntyped', kinshipGraph)
            CaseService.buildDefenceVertex(3, '', None, 'F', 'MUntyped', kinshipGraph)
            CaseService.buildProsecutionVertex(2, '', None, 'F', 'Mother', kinshipGraph)
        elif(noOfSubjects == 2 and caseType == 'Duo Fatherless'):
            CaseService.buildDefenceVertex(3, '', None, 'M', 'FUntyped', kinshipGraph)
            CaseService.buildDefenceVertex(3, '', None, 'F', 'MUntyped', kinshipGraph)
            CaseService.buildProsecutionVertex(2, '', None, 'M', 'Father', kinshipGraph)    

        CaseService.buildEdge(2 ,kinshipGraph['fatherNodeId']  ,kinshipGraph['motherNodeId'] ,None , kinshipGraph);
        CaseService.buildEdge(2 ,kinshipGraph['childNodeId']  ,kinshipGraph['prosVertexId'] ,'Vertex' , kinshipGraph)

        if(noOfSubjects == 3 and caseType == 'Trio Paternity'):
            CaseService.buildEdge(3 ,kinshipGraph['untypedFatherNodeId']  ,kinshipGraph['defMotherNodeId'],None, kinshipGraph )
            CaseService.buildEdge(3 ,kinshipGraph['defChildNodeId'],kinshipGraph['defVertexId'] ,'Vertex', kinshipGraph  )
        elif(noOfSubjects == 3 and caseType == 'Trio Maternity'):
            CaseService.buildEdge(3 ,kinshipGraph['untypedMotherNodeId']  ,kinshipGraph['defFatherNodeId'],None, kinshipGraph )
            CaseService.buildEdge(3 ,kinshipGraph['defChildNodeId'],kinshipGraph['defVertexId'] ,'Vertex', kinshipGraph  )    
        elif(noOfSubjects == 2 and caseType == 'Duo Motherless' ):
            CaseService.buildEdge(3 , kinshipGraph['untypedFatherNodeId']  ,kinshipGraph['untypedMotherNodeId'] ,None, kinshipGraph )
            CaseService.buildEdge(3 ,kinshipGraph['defChildNodeId']  ,kinshipGraph['defVertexId'] ,'Vertex' , kinshipGraph)
        elif(noOfSubjects == 2 and caseType == 'Duo Fatherless' ):
            CaseService.buildEdge(3 , kinshipGraph['untypedFatherNodeId']  ,kinshipGraph['untypedMotherNodeId'] ,None, kinshipGraph )
            CaseService.buildEdge(3 ,kinshipGraph['defChildNodeId']  ,kinshipGraph['defVertexId'] ,'Vertex' , kinshipGraph)
                
        #print(kinshipGraph)
        jsonKinshipGraph = json.dumps(kinshipGraph)
        #print(jsonKinshipGraph)
        return kinshipGraph    
    
    @staticmethod
    def createReport(baseUrl,caseId,analysisId):
        CaseService.logService('createReport' )
        reportTemplateUrl = baseUrl+'/platform/common/template/getTemplateByGroup/Kinship%20Report'
        reportTemplteDict = GateWayService.callConverge(reportTemplateUrl, 'false', '')
        #print(reportTemplteDict)
        reportTemplteAccessionId = reportTemplteDict[0]['templateAccessionId']
        kinshipReportInputDataDict = {'templateAccessionID': reportTemplteAccessionId, 'reportName': 'Report created from script', 'conclusion': None, 'caseID': caseId, 'analysisID': analysisId }
        kinshipReportInputDataJson = json.dumps(kinshipReportInputDataDict)
        reportGenerationUrl = baseUrl+'/kinship/kinship/createKinshipReport/'+str(caseId)
        flushableQ.put(caseId)
        GateWayService.callConverge(reportGenerationUrl, 'true', kinshipReportInputDataJson)

    @staticmethod 
    def performAnalysis(baseUrl, dnaCaseDict,profilesDict,subjects): 
        caseId = dnaCaseDict['id']
        caseUid = dnaCaseDict['uid'] 
        caseType = dnaCaseDict['caseType'] 
        analysisInputDict = CaseService.getAnalysisInput(caseId, baseUrl)
        kinshipGraph = CaseService.buildGraph(caseId,caseType,profilesDict,subjects)
        analysisId = CaseService.saveAnalysisInput(baseUrl,caseId, caseUid, analysisInputDict, kinshipGraph)
        #CaseService.creatPedigreeTreeImageForCase(baseUrl, caseId, analysisId)
        analysisResultsDict = CaseService.calculate(baseUrl, caseId, analysisId);
        analysisResults = json.dumps(analysisResultsDict)
        CaseService.saveAnalysisResults(baseUrl, caseId, analysisId, analysisResults)
        encodedString = CaseService.getEncodedStringGorImage(baseUrl,dnaCaseDict['caseType'],subjects)
        CaseService.creatPedigreeTreeImageForCase(baseUrl,analysisId,encodedString,'414','919','ScriptedQuickKinshipModel')   
        return analysisId
    
    @staticmethod    
    def creatPedigreeTreeImageForCase(baseUrl,analysisID,decodeString,height,width,modelName):    
        CaseService.logService('creatPedigreeTreeImageForCase' )
        addSubjectUrl = baseUrl+'/kinship/kinship/saveSessionImage/'+str(analysisID)
        kinshipImageModelDict = {'decodeString':decodeString, 'height':height,'width':width, 'modelName':modelName} 
        kinshipImageModel = json.dumps(kinshipImageModelDict)
        return GateWayService.callConverge(addSubjectUrl,'true', kinshipImageModel)
            
    @staticmethod
    def getEncodedStringGorImage(baseUrl,caseType,subjects):
        isFemale = 'false'
        for id, subject in subjects.items():
            relationship = subject['relationship']
            gender =  subject['gender']
            if( relationship == RelationshipEnum.Relationship.child.value):
                if(gender == 'F'):
                    isFemale = 'true'
                
        data = CaseService.getPedigreeTreeXml(baseUrl, caseType)
        data = re.sub('/\\"/g', '"', data)
        data = re.sub('/^"(.*)"$/', '$1', data)
        root = et.fromstring(data)
        
        #print(isFemale)
        #if(isFemale == 'true'):
            #for image in root.findall('.//image[@relation="Child"][@src="/ui/img/male.png"]'):
                #print (image.attrib)
        #else:
            #for image in root.findall('.//image[@relation="Child"][@src="/ui/img/female.png"]'):
                #print (image.attrib)
                
        if(isFemale == 'true'):
            for image in root.findall('.//image[@relation="Child"][@src="/ui/img/male.png"]'):
                root.remove(image)
        else:   
            for image in root.findall('.//image[@relation="Child"][@src="/ui/img/female.png"]'):
                root.remove(image)
                            
        for image in root.findall('image'):
            for name, value in image.attrib.items():
                if(name == 'src'):
                    value =  baseUrl + value
                    image.attrib['src'] =value
                      
        

                            
        xmlstr = et.tostring(root)   
        #print( xmlstr)
        encodedString= urllib.parse.quote(xmlstr)
        #print(encodedString)
        return  encodedString
    
    @staticmethod 
    def saveAnalysisInput(baseUrl,caseId, caseUid,analysisInputDict,kinshipGraph): 
        analysisInputDict['graph'] = kinshipGraph['graph']
        analysisInputDict['warnings']=[]
        analysisInputDict['caseUid']=caseUid
        analysisInput = json.dumps(analysisInputDict)
        return  CaseService.postAnalysisInput(caseId, baseUrl,analysisInput)
    @staticmethod 
    def buildProsecutionVertex(containerId , subjectId , profileId , gender , relationShip, kinshipGraph):
        vertex = {'id':kinshipGraph['seqId'] ,'containerId':containerId,'gender':gender, 'subjectId':subjectId, 'profileId': profileId}
        kinshipGraph['graph']['vertices'].append(vertex)
        if(relationShip == 'Mother'):
            kinshipGraph['motherNodeId'] = kinshipGraph['seqId']
        elif(relationShip == 'Father'):
            kinshipGraph['fatherNodeId'] = kinshipGraph['seqId']
        elif(relationShip == 'Child'):
            kinshipGraph['childNodeId'] = kinshipGraph['seqId']
        kinshipGraph['seqId'] = kinshipGraph['seqId'] + 1
    
    @staticmethod 
    def buildDefenceVertex(containerId ,subjectId , profileId , gender , relationShip,  kinshipGraph):
        vertex = {'id':kinshipGraph['seqId'] ,'containerId':containerId,'gender':gender, 'subjectId':subjectId, 'profileId': profileId}  
        kinshipGraph['graph']['vertices'].append(vertex)
        #print(relationShip)
        if(relationShip == 'Mother'):
            kinshipGraph['defMotherNodeId'] = kinshipGraph['seqId']
        elif(relationShip == 'Father'):
            kinshipGraph['defFatherNodeId'] = kinshipGraph['seqId']
        elif(relationShip == 'Biological Father'):
            kinshipGraph['defFatherNodeId'] = kinshipGraph['seqId']    
        elif(relationShip =='Child'):
            kinshipGraph['defChildNodeId'] = kinshipGraph['seqId']
        elif(relationShip =='FUntyped'):
            kinshipGraph['untypedFatherNodeId' ]= kinshipGraph['seqId']
        elif(relationShip == 'MUntyped'):
            kinshipGraph['untypedMotherNodeId'] = kinshipGraph['seqId']
        kinshipGraph['seqId'] = kinshipGraph['seqId'] + 1;

        
    @staticmethod 
    def buildEdge(containerId , sourceId ,targetId, type,   kinshipGraph):
        edge = {'id':kinshipGraph['seqId'], 'containerId':containerId, 'sourceId': sourceId, 'targetId': targetId}  
        kinshipGraph['graph']['edges'].append(edge)
        if(type != 'Vertex'):
            if(containerId == 2):
                kinshipGraph['prosVertexId'] = kinshipGraph['seqId']
            elif(containerId == 3):
                kinshipGraph['defVertexId'] = kinshipGraph['seqId'];
        kinshipGraph['seqId'] = kinshipGraph['seqId'] + 1;
        
     
    # Master data related   API  
    
    @staticmethod    
    def deleteDictionaryEntries(id, baseUrl ):
        CaseService.logService('getDictionaryEntries' )
        getDictUrl = baseUrl+'/platform/common/dictionary/'+str(id)
        return GateWayService.callConvergeRestApi(getDictUrl, 'DELETE', '')
    
    @staticmethod    
    def getDictionaryEntries(category, baseUrl ):
        CaseService.logService('getDictionaryEntries' )
        getDictUrl = baseUrl+'/platform/common/dictionary/entries?category='+category
        return GateWayService.callConverge(getDictUrl, 'false', '')
    
    @staticmethod    
    def saveDictionaryEntries(baseUrl, dictionaryEntry ):
        CaseService.logService('saveDictionaryEntries' )
        getDictUrl = baseUrl+'/platform/common/dictionary/'
        return GateWayService.callConverge(getDictUrl, 'true', dictionaryEntry)
    
    @staticmethod    
    def getDictionaryEntriesWithParent(category, parentCategory, baseUrl ):
        CaseService.logService('getDictionaryEntriesWithParent' )
        getDictUrl = baseUrl+'/platform/common/dictionary/entries?category='+category+'&parent='+parentCategory
        return GateWayService.callConverge(getDictUrl,'false', '')
   
    @staticmethod    
    def getAllKits(baseUrl):
        CaseService.logService('getAllKits' )
        getDictUrl = baseUrl+'/platform/profile/kit/getAllKits'
        return GateWayService.callConverge(getDictUrl,'false', '')
    
    @staticmethod    
    def getAllMasterData(baseUrl):
        CaseService.logService('getAllMasterData' )
        getDictUrl = baseUrl+'/kinship/kinshipAdmin/masterDataWithEthnicity'
        return GateWayService.callConverge(getDictUrl,'false', '')
    
    @staticmethod    
    def getDefaultMasterData(baseUrl):
        CaseService.logService('getDefaultMasterData' )
        getDictUrl = baseUrl+'/platform/common/dictionary/MasDat'
        return GateWayService.callConverge(getDictUrl,'false', '')
    
    @staticmethod 
    def getAllEthinicity(masterDataName, baseUrl):
        CaseService.logService('getAllEthinicity' )
        getEthinictyUrl = baseUrl+'/kinship/kinshipAdmin/getEthnicityForSubject/'+masterDataName
        return GateWayService.callConverge(getEthinictyUrl,'false', '')
    
    @staticmethod 
    def getAllCaseTypes(baseUrl):
        CaseService.logService('getAllEthinicity' )
        getCaseTypeurl = baseUrl+'/platform/common/dictionary/entries?category=CaseType'
        return GateWayService.callConverge(getCaseTypeurl,'false', '')
    
    
    @staticmethod
    def logService(methodName):
        print ( 'In method ' + methodName)
        logging.info('In method ' + methodName)
    



'''
Created on May 03, 2015
import requests

@author: karpagm1
'''
from enum import Enum

    
class EthinicityEnum(Enum):
    asian = 'Asian'
    seHispanic = 'SEHispanic'
    caucasian = 'Caucasian'
    africanAmerican = 'African American'
    swHispanic = 'SWHispanic'
    
    
    
    
    



import configparser
from authentication.authentication import Authentication
from service.batchService import BatchService
import sys,os
import json

class Batch:
	def __init__(self,userName,password):
		self.baseUrl = ''
		self.ngsUri = ''
		self.userName = userName
		self.password = password
		self.config = configparser.RawConfigParser()
		self.package_dir = os.path.dirname(os.path.abspath(__file__))
		self.readCfg()
		self.login()
		

	def readCfg(self):
		self.config.read(os.path.join(self.package_dir,'init.cfg'))
		self.baseUrl = self.config.get('urls','base_dir')
		self.ngsUri = self.config.get('ngs','base_uri')

	def login(self):
		self.auth = Authentication()
		self.auth.performLogin(self.baseUrl,self.userName,self.password)

	def logOut(self):
		self.auth.performLogOut(self.baseUrl,self.userName)

	def getAll(self):
		batchDashborad = BatchService.getAll(self.baseUrl)
		return batchDashborad

	def get(self,batchId):
		batch = BatchService.get(self.baseUrl,batchId)
		return batch

	def getResultsCardData(self,batchId):
		return BatchService.getResultsCardData(self.baseUrl,self.ngsUri,batchId)

	def getTaskReview(self,taskId):
		return BatchService.getTaskReview(self.baseUrl,self.ngsUri,taskId)

	













'''
Created on Apr 27, 2015
import requests

@author: karpagm1
'''
from service import LocusViewObject



    
class GenotypeLocusViewObject:
    
    def __init__(self):
        self.id = None
        self.locus = None
        self.value = None
        
    def __repr__(self):
        return {'id':self.id,'locus':self.locus,'value':self.value}       


'''
Created on Apr 27, 2015
import requests

@author: karpagm1
'''


class SubjectViewObject:

    def __init__(self):
        self.ageAtRegistration = None
        self.birthDate = None
        # self.contact
        self.ethnicityId = None
        self.ethnicityName = None
        self.externalAppId = None
        self.externalId = None
        self.firstName = None
        self.gender = None
        self.lastComment = None
        self.lastName = None
        self.middleName = None
        self.relationship = None
        self.title = None
        self.id = None
        self.uid = None
        
    def __repr__(self):
        return {'id':self.id}       
        #return {'ageAtRegistration':self.ageAtRegistration,'birthDate':self.birthDate,'ethnicityId':self.ethnicityId,'ethnicityName':self.ethnicityName,'externalAppId':self.externalAppId,'externalId':self.externalId,'firstName':self.firstName,'gender':self.gender,'lastComment':self.lastComment,'lastName':self.lastName,'middleName':self.middleName,'relationship':self.relationship,'title':self.title,'id':self.id,'uid':self.uid}      
        



import logging
import json

from authentication.gateway import GateWayService
import xml.etree.ElementTree as et
import urllib
import re
from service import RelationshipEnum
from service.DictionaryEntry import DictionaryEntry
from QueueModule.q import flushableQ


class BatchService:
	def __init__():
		pass

	@staticmethod
	def getAll(baseUrl):
		url = baseUrl+'/platform/common/searchEngine/search?language=en_US'
		payload = json.dumps({"fetchContext":"com.lifetech.converge.domain.Batch",
			                  "filterContext":"com.lifetech.converge.domain.Batch",
			                  "attributes":["uid"],
			                  "operands":["NOT NULL"],
			                  "values":[None],
			                  "dataTypeArray":["String"],
			                  "filterCriteria":[],
			                  "fetchAttributes":["id","uid","externalUid","name","status","taskType.name","description","operator.userName","startedTime","completedTime","method.name","createdTime","updatedTime"]})
		return GateWayService.callConverge(url, 'true', payload)

	@staticmethod
	def get(baseUrl,batchId):
		url = baseUrl+'/platform/common/searchEngine/search?language=en_US'
		payload = json.dumps({"fetchContext":"com.lifetech.converge.domain.Batch",
			                  "filterContext":"com.lifetech.converge.domain.Batch",
			                  "attributes":["uid"],
			                  "operands":["="],
			                  "values":[batchId],
			                  "dataTypeArray":["String"],
			                  "filterCriteria":[],
			                  "fetchAttributes":["id","uid","externalUid","name","status","taskType.name","description","operator.userName","startedTime","completedTime","method.name","createdTime","updatedTime"]})
		return GateWayService.callConverge(url, 'true', payload)


	@staticmethod
	def getResultsCardData(baseUrl,ngsUri,batchId):
		batch = BatchService.get(baseUrl,batchId)[0]
		if batch:
			url = baseUrl+ngsUri+'/batch/getResultsCardData/'+str(batch['id'])+'?language=en_US'
			payload = {}
			return GateWayService.callConverge(url, 'false', payload)
		else:
			return []

	@staticmethod
	def getTaskReview(baseUrl,ngsUri,taskId):
		url = baseUrl+ngsUri+'/task/review/'+str(taskId)+'/STR?language=en_US'
		payload = {}
		return GateWayService.callConverge(url, 'false', payload)











'''
Created on Apr 27, 2015
import requests

@author: karpagm1
'''


    
class GenotypeProfileViewObject:
    
    def __init__(self):
        self.id = None
        self.uid = None
        self.lastModified = None
        self.createdDate = None
        self.kitName = None
        self.locusTypeName = None
        self.isVirtual = None
        self.subject = None
        self.sample = None #not required for post.
        self.isDefault = None
        self.bioSampleUID = None
        self.sampleUID = None
        self.bioSampleExternalUid = None
        self.kitId = None
        self.genotypeLoci = None
        self.profileCategory = None
        self.errorMessage = None
        self.profileCategoryValid = None
        self.dnaCaseUpdateDate = None
        self.imported = None